<?php
namespace Bushelpowered\Api\Aggregator\Crm\V1\Response;
        
class ActivityResponse implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $activityType The type of activity: note, calltext, email, task, meeting*/
    public string $activityType;
    /** @var string $content The content of the activity, editable, 1000 character limit*/
    public string $content;
    /** @var null|string $assignedTo the UUID of the user that the task is assigned to*/
    public ?string $assignedTo = null;
    /** @var null|string $dueDate the due date of the task of yyyy-MM-dd format, IE: 2023-10-04*/
    public ?string $dueDate = null;
    /** @var null|string $completedBy The name of the user that completed the activity*/
    public ?string $completedBy = null;
    /** @var null|string $completedAt the date the task was marked as completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $completedAt = null;
    /** @var string $createdBy The name of the user that created the activity*/
    public string $createdBy;
    /** @var string $updatedBy The name of the user that updated the activity*/
    public string $updatedBy;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $activityType The type of activity: note, calltext, email, task, meeting
     * @param  string  $content The content of the activity, editable, 1000 character limit
     * @param  null|string  $assignedTo the UUID of the user that the task is assigned to
     * @param  null|string  $dueDate the due date of the task of yyyy-MM-dd format, IE: 2023-10-04
     * @param  null|string  $completedBy The name of the user that completed the activity
     * @param  null|string  $completedAt the date the task was marked as completed of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdBy The name of the user that created the activity
     * @param  string  $updatedBy The name of the user that updated the activity
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $activityType, string $content, ?string $assignedTo, ?string $dueDate, ?string $completedBy, ?string $completedAt, string $createdBy, string $updatedBy, string $createdAt, string $updatedAt)
    {
        $this->id = $id;
        $this->activityType = $activityType;
        $this->content = $content;
        $this->assignedTo = $assignedTo;
        $this->dueDate = $dueDate;
        $this->completedBy = $completedBy;
        $this->completedAt = $completedAt;
        $this->createdBy = $createdBy;
        $this->updatedBy = $updatedBy;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
}