<?php
namespace Bushelpowered\Api\Grain\Contracts\V1\Model;
        
class PricingLineStandard implements \Bushelpowered\Api\Common\HasSourceTimestamps, \Bushelpowered\Api\Common\HasTimestamps
{
    /** @var string $id The primary unique identifier.*/
    public string $id;
    /** @var string $entityRevisionId The revision idempotency key.*/
    public string $entityRevisionId;
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var null|string $sourceLocationId The source location identifier.*/
    public ?string $sourceLocationId = null;
    /** @var null|string $locationId The location identifier.*/
    public ?string $locationId = null;
    /** @var string $sourceContractId The source contract identifier.*/
    public string $sourceContractId;
    /** @var string $contractId The bushel contract identifier.*/
    public string $contractId;
    /** @var null|float $sourceBasisPrice The basis price, which is an adjustment to the future price offsetting costs incurred by the buyer.*/
    public ?float $sourceBasisPrice = null;
    /** @var null|float $sourceCashPrice The cash price, which is the maximum value per unit the seller can receive.*/
    public ?float $sourceCashPrice = null;
    /** @var null|string $sourceCurrency The currency in which the contract is transacted.*/
    public ?string $sourceCurrency = null;
    /** @var null|string $currency Standardized currency in which the contract is transacted.*/
    public ?string $currency = null;
    /** @var null|string $sourceDeliveryPeriodStart The delivery period start date. Delivery periods are derived from futures months and, generally, start along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeliveryPeriodStart = null;
    /** @var null|string $sourceDeliveryPeriodEnd The delivery period end date. Delivery periods are derived from futures months and, generally, end along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeliveryPeriodEnd = null;
    /** @var null|string $sourceDeliveryStatus Some value defining the current delivery status. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unfilled/Filled.*/
    public ?string $sourceDeliveryStatus = null;
    /** @var null|string $sourceDisplayId The grower-friendly identifier for the pricing line. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique, compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.*/
    public ?string $sourceDisplayId = null;
    /** @var null|string $sourceFuturesMonth The future month, or the month during which a commodity would be brought to market.*/
    public ?string $sourceFuturesMonth = null;
    /** @var null|float $sourceFuturesPrice The future price, which is the month-specific market rate for a commodity.*/
    public ?float $sourceFuturesPrice = null;
    /** @var null|string $sourcePricedAt The date-time when pricing was applied, v.v. optional. Repeatedly considered removing it. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourcePricedAt = null;
    /** @var null|string $sourcePricingStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unpriced/Priced.*/
    public ?string $sourcePricingStatus = null;
    /** @var null|float $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this pricing line.*/
    public ?float $sourceQuantityDelivered = null;
    /** @var null|float $sourceQuantityPriced The quantity of priced units.*/
    public ?float $sourceQuantityPriced = null;
    /** @var null|string $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.*/
    public ?string $sourceQuantityUom = null;
    /** @var null|string $quantityUom Standardized unit of measure.*/
    public ?string $quantityUom = null;
    /** @var null|float $sourceEstimatedAdditionalAdjustment The estimated additional adjustments on the contracts that are not priced yet. This can be, or is typically, used with OTC/option contracts to display the adjustment value at present time for bushels not priced.*/
    public ?float $sourceEstimatedAdditionalAdjustment = null;
    /** @var null|float $sourceEstimatedFutures The estimated futures price of the bushels remaining on contract that do not have a futures price.*/
    public ?float $sourceEstimatedFutures = null;
    /** @var null|float $sourceAdjustment The total priced adjustments for a contract, whether they are fees, premiums, freight or other.*/
    public ?float $sourceAdjustment = null;
    /** @var null|int $sourceSequenceNumber The source-defined ordinality of a pricing line.*/
    public ?int $sourceSequenceNumber = null;
    /** @var null|string $sourceSignatureStatus Some value defining whether a pricing line is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.*/
    public ?string $sourceSignatureStatus = null;
    /** @var null|string $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!*/
    public ?string $sourceComments = null;
    /** @var \Bushelpowered\Api\Grain\Contracts\V1\Model\PricingHistoryStandard[]|null $pricingHistories */
    public ?array $pricingHistories = null;
    /** @var string $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;
    /** @var null|string $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $deletedAt = null;

    /**
     * @param  string  $id The primary unique identifier.
     * @param  string  $entityRevisionId The revision idempotency key.
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  null|string  $sourceLocationId The source location identifier.
     * @param  null|string  $locationId The location identifier.
     * @param  string  $sourceContractId The source contract identifier.
     * @param  string  $contractId The bushel contract identifier.
     * @param  null|float  $sourceBasisPrice The basis price, which is an adjustment to the future price offsetting costs incurred by the buyer.
     * @param  null|float  $sourceCashPrice The cash price, which is the maximum value per unit the seller can receive.
     * @param  null|string  $sourceCurrency The currency in which the contract is transacted.
     * @param  null|string  $currency Standardized currency in which the contract is transacted.
     * @param  null|string  $sourceDeliveryPeriodStart The delivery period start date. Delivery periods are derived from futures months and, generally, start along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeliveryPeriodEnd The delivery period end date. Delivery periods are derived from futures months and, generally, end along with calendar months. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeliveryStatus Some value defining the current delivery status. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unfilled/Filled.
     * @param  null|string  $sourceDisplayId The grower-friendly identifier for the pricing line. Growers are typically only ever exposed to a single identifier which is often a small part of a larger, unique, compound-identifier. Notwithstanding, this ID is vital for applications of the data which are intended to primarily be understood by humans.
     * @param  null|string  $sourceFuturesMonth The future month, or the month during which a commodity would be brought to market.
     * @param  null|float  $sourceFuturesPrice The future price, which is the month-specific market rate for a commodity.
     * @param  null|string  $sourcePricedAt The date-time when pricing was applied, v.v. optional. Repeatedly considered removing it. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourcePricingStatus Some value defining whether a contract is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unpriced/Priced.
     * @param  null|float  $sourceQuantityDelivered The quantity of delivered units. Tracks the net delivered units of the contracted commodity applied to this pricing line.
     * @param  null|float  $sourceQuantityPriced The quantity of priced units.
     * @param  null|string  $sourceQuantityUom The unit of measure by which the quantities are measured, such as bushels.
     * @param  null|string  $quantityUom Standardized unit of measure.
     * @param  null|float  $sourceEstimatedAdditionalAdjustment The estimated additional adjustments on the contracts that are not priced yet. This can be, or is typically, used with OTC/option contracts to display the adjustment value at present time for bushels not priced.
     * @param  null|float  $sourceEstimatedFutures The estimated futures price of the bushels remaining on contract that do not have a futures price.
     * @param  null|float  $sourceAdjustment The total priced adjustments for a contract, whether they are fees, premiums, freight or other.
     * @param  null|int  $sourceSequenceNumber The source-defined ordinality of a pricing line.
     * @param  null|string  $sourceSignatureStatus Some value defining whether a pricing line is considered signed. Intended to capture the breadth of business logic to enable a more robust understanding of the intent behind assigned values. Previously a boolean, up-scales to Unsigned/Signed.
     * @param  null|string  $sourceComments Additional comments about the contract. Occasionally, about the grower... Seriously, these values may not be intended to be shown to some consumers!
     * @param  \Bushelpowered\Api\Grain\Contracts\V1\Model\PricingHistoryStandard[]|null  $pricingHistories 
     * @param  string  $sourceCreatedAt Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $deletedAt Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, string $entityRevisionId, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceLocationId, ?string $locationId, string $sourceContractId, string $contractId, ?float $sourceBasisPrice, ?float $sourceCashPrice, ?string $sourceCurrency, ?string $currency, ?string $sourceDeliveryPeriodStart, ?string $sourceDeliveryPeriodEnd, ?string $sourceDeliveryStatus, ?string $sourceDisplayId, ?string $sourceFuturesMonth, ?float $sourceFuturesPrice, ?string $sourcePricedAt, ?string $sourcePricingStatus, ?float $sourceQuantityDelivered, ?float $sourceQuantityPriced, ?string $sourceQuantityUom, ?string $quantityUom, ?float $sourceEstimatedAdditionalAdjustment, ?float $sourceEstimatedFutures, ?float $sourceAdjustment, ?int $sourceSequenceNumber, ?string $sourceSignatureStatus, ?string $sourceComments, ?array $pricingHistories, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt, string $createdAt, string $updatedAt, ?string $deletedAt)
    {
        $this->id = $id;
        $this->entityRevisionId = $entityRevisionId;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceLocationId = $sourceLocationId;
        $this->locationId = $locationId;
        $this->sourceContractId = $sourceContractId;
        $this->contractId = $contractId;
        $this->sourceBasisPrice = $sourceBasisPrice;
        $this->sourceCashPrice = $sourceCashPrice;
        $this->sourceCurrency = $sourceCurrency;
        $this->currency = $currency;
        $this->sourceDeliveryPeriodStart = $sourceDeliveryPeriodStart;
        $this->sourceDeliveryPeriodEnd = $sourceDeliveryPeriodEnd;
        $this->sourceDeliveryStatus = $sourceDeliveryStatus;
        $this->sourceDisplayId = $sourceDisplayId;
        $this->sourceFuturesMonth = $sourceFuturesMonth;
        $this->sourceFuturesPrice = $sourceFuturesPrice;
        $this->sourcePricedAt = $sourcePricedAt;
        $this->sourcePricingStatus = $sourcePricingStatus;
        $this->sourceQuantityDelivered = $sourceQuantityDelivered;
        $this->sourceQuantityPriced = $sourceQuantityPriced;
        $this->sourceQuantityUom = $sourceQuantityUom;
        $this->quantityUom = $quantityUom;
        $this->sourceEstimatedAdditionalAdjustment = $sourceEstimatedAdditionalAdjustment;
        $this->sourceEstimatedFutures = $sourceEstimatedFutures;
        $this->sourceAdjustment = $sourceAdjustment;
        $this->sourceSequenceNumber = $sourceSequenceNumber;
        $this->sourceSignatureStatus = $sourceSignatureStatus;
        $this->sourceComments = $sourceComments;
        $this->pricingHistories = $pricingHistories;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
        $this->deletedAt = $deletedAt;
    }
    
    /**
     * @return string Created date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string Updated date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string Deleted date-time from data source. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
    /**
     * @return null|string Deleted date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getDeletedAt(): ?string
    {
        return $this->deletedAt;
    }
}