<?php
namespace Bushelpowered\Api\Platform\Authorization\V1\Event;
        
class AccountIdentifiersRaw implements \Bushelpowered\Api\Common\Event\RawRecord, \Bushelpowered\Api\Common\HasSourceTimestamps
{
    /** @var null|string $sourceName The name of the account in the remote system.*/
    public ?string $sourceName = null;
    /** @var \Bushelpowered\Api\Platform\Authorization\V1\Event\IdentifierRoles[] $identifierRoles An exhaustive list of identifiers for this Account for this datasource. Also includes */
    public array $identifierRoles;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt When provided this will remove all associations to accounts for this identifier ONLY at this datasource. This is functionally the same as sending an empty list of accounts. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;
    /** @var string $tenantId The id of the tenant this record belongs to.*/
    public string $tenantId;
    /** @var string $datasourceId The id of the datasource this record came from.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique id of the data in the source repository (often an ERP DB), often the concatenation of the datasource and source identifier to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.*/
    public string $sourceId;
    /** @var null|string $sourceAccountId The datasource's remote id of the account that owns this record, if any.*/
    public ?string $sourceAccountId = null;
    /** @var null|string $sourceLocationId The datasource's remote id of the location that owns this record, if any.*/
    public ?string $sourceLocationId = null;

    /**
     * @param  null|string  $sourceName The name of the account in the remote system.
     * @param  \Bushelpowered\Api\Platform\Authorization\V1\Event\IdentifierRoles[]  $identifierRoles An exhaustive list of identifiers for this Account for this datasource. Also includes 
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt When provided this will remove all associations to accounts for this identifier ONLY at this datasource. This is functionally the same as sending an empty list of accounts. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $tenantId The id of the tenant this record belongs to.
     * @param  string  $datasourceId The id of the datasource this record came from.
     * @param  string  $integrationId The global unique id of the data in the source repository (often an ERP DB), often the concatenation of the datasource and source identifier to ensure uniqueness.
     * @param  string  $sourceId The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.
     * @param  null|string  $sourceAccountId The datasource's remote id of the account that owns this record, if any.
     * @param  null|string  $sourceLocationId The datasource's remote id of the location that owns this record, if any.
     */
    public function __construct(?string $sourceName, array $identifierRoles, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt, string $tenantId, string $datasourceId, string $integrationId, string $sourceId, ?string $sourceAccountId, ?string $sourceLocationId)
    {
        $this->sourceName = $sourceName;
        $this->identifierRoles = $identifierRoles;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceAccountId = $sourceAccountId;
        $this->sourceLocationId = $sourceLocationId;
    }
    
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string When provided this will remove all associations to accounts for this identifier ONLY at this datasource. This is functionally the same as sending an empty list of accounts. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
    /**
     * @return string The id of the tenant this record belongs to.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The id of the datasource this record came from.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique id of the data in the source repository (often an ERP DB), often the concatenation of the datasource and source identifier to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The datasource's remote id of the account that owns this record, if any.
     */
    public function getSourceAccountId(): ?string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return null|string The datasource's remote id of the location that owns this record, if any.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
}