<?php
namespace Bushelpowered\Api\Platform\Authorization\V1\Event;
        
class IdentifierAccountsRaw implements \Bushelpowered\Api\Common\Event\RawRecord, \Bushelpowered\Api\Common\HasSourceTimestamps
{
    /** @var string $userIdpId The identifier for the user in the specified IDP*/
    public string $userIdpId;
    /** @var string $idpSlug The slug that specifies which identity provider should be used to authenticate this account binding.*/
    public string $idpSlug;
    /** @var null|string $name The name of the user that this identifies.*/
    public ?string $name = null;
    /** @var \Bushelpowered\Api\Platform\Authorization\V1\Event\AccountRoles[] $accountRoles An exhaustive list of accounts for this Identifier at for this datasource.*/
    public array $accountRoles;
    /** @var string $integrationId The global unique id of the data in the identity provider, often the concatenation of the idpSlug and userIdpId to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var null|string $sourceDeletedAt When provided this will remove all associations to accounts for this identifier ONLY at this datasource. This is functionally the same as sending an empty list of accounts. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;
    /** @var string $tenantId The id of the tenant this record belongs to.*/
    public string $tenantId;
    /** @var string $datasourceId The id of the datasource this record came from.*/
    public string $datasourceId;
    /** @var string $sourceId The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.*/
    public string $sourceId;
    /** @var null|string $sourceAccountId The datasource's remote id of the account that owns this record, if any.*/
    public ?string $sourceAccountId = null;
    /** @var null|string $sourceLocationId The datasource's remote id of the location that owns this record, if any.*/
    public ?string $sourceLocationId = null;

    /**
     * @param  string  $userIdpId The identifier for the user in the specified IDP
     * @param  string  $idpSlug The slug that specifies which identity provider should be used to authenticate this account binding.
     * @param  null|string  $name The name of the user that this identifies.
     * @param  \Bushelpowered\Api\Platform\Authorization\V1\Event\AccountRoles[]  $accountRoles An exhaustive list of accounts for this Identifier at for this datasource.
     * @param  string  $integrationId The global unique id of the data in the identity provider, often the concatenation of the idpSlug and userIdpId to ensure uniqueness.
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt When provided this will remove all associations to accounts for this identifier ONLY at this datasource. This is functionally the same as sending an empty list of accounts. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $tenantId The id of the tenant this record belongs to.
     * @param  string  $datasourceId The id of the datasource this record came from.
     * @param  string  $sourceId The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.
     * @param  null|string  $sourceAccountId The datasource's remote id of the account that owns this record, if any.
     * @param  null|string  $sourceLocationId The datasource's remote id of the location that owns this record, if any.
     */
    public function __construct(string $userIdpId, string $idpSlug, ?string $name, array $accountRoles, string $integrationId, string $sourceCreatedAt, string $sourceUpdatedAt, ?string $sourceDeletedAt, string $tenantId, string $datasourceId, string $sourceId, ?string $sourceAccountId, ?string $sourceLocationId)
    {
        $this->userIdpId = $userIdpId;
        $this->idpSlug = $idpSlug;
        $this->name = $name;
        $this->accountRoles = $accountRoles;
        $this->integrationId = $integrationId;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->sourceId = $sourceId;
        $this->sourceAccountId = $sourceAccountId;
        $this->sourceLocationId = $sourceLocationId;
    }
    
    /**
     * @return string The global unique id of the data in the identity provider, often the concatenation of the idpSlug and userIdpId to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return null|string When provided this will remove all associations to accounts for this identifier ONLY at this datasource. This is functionally the same as sending an empty list of accounts. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
    /**
     * @return string The id of the tenant this record belongs to.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The id of the datasource this record came from.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The id of the data in the source repository (often an ERP/DB). Unique only in the context of it's data source.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The datasource's remote id of the account that owns this record, if any.
     */
    public function getSourceAccountId(): ?string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return null|string The datasource's remote id of the location that owns this record, if any.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
}