<?php
namespace Bushelpowered\Api\Platform\File\V1\Common;
        
class File implements \Bushelpowered\Api\Common\HasCreatedAtTimestamp, \Bushelpowered\Api\Common\HasUpdatedAtTimestamp
{
    /** @var string $id The file id*/
    public string $id;
    /** @var \Bushelpowered\Api\Platform\File\V1\Common\FileStore $store */
    public \Bushelpowered\Api\Platform\File\V1\Common\FileStore $store;
    /** @var \Bushelpowered\Api\Platform\File\V1\Common\FileType $fileType */
    public \Bushelpowered\Api\Platform\File\V1\Common\FileType $fileType;
    /** @var string $displayName The display name of the file. e.g. my file*/
    public string $displayName;
    /** @var string $contentType The validated IANA media type (mime type) of the file. e.g. image/png or application/pdf.*/
    public string $contentType;
    /** @var string $sourceFileName The name of the file provided by the client.*/
    public string $sourceFileName;
    /** @var string $sourceContentType The IANA media type (mime type) of the file provided by the client.*/
    public string $sourceContentType;
    /** @var int $size The size of the file in bytes*/
    public int $size;
    /** @var string $createdBy The user who created the file.*/
    public string $createdBy;
    /** @var null|string $url The url of the file. Only returned when the includeFileUrls option is provided.*/
    public ?string $url = null;
    /** @var \Bushelpowered\Api\Platform\File\V1\Common\Attachment[]|null $attachments The file attachments. Only returned when the includeAttachments option is provided.*/
    public ?array $attachments = null;
    /** @var string $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $createdAt;
    /** @var string $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $updatedAt;

    /**
     * @param  string  $id The file id
     * @param  \Bushelpowered\Api\Platform\File\V1\Common\FileStore  $store 
     * @param  \Bushelpowered\Api\Platform\File\V1\Common\FileType  $fileType 
     * @param  string  $displayName The display name of the file. e.g. my file
     * @param  string  $contentType The validated IANA media type (mime type) of the file. e.g. image/png or application/pdf.
     * @param  string  $sourceFileName The name of the file provided by the client.
     * @param  string  $sourceContentType The IANA media type (mime type) of the file provided by the client.
     * @param  int  $size The size of the file in bytes
     * @param  string  $createdBy The user who created the file.
     * @param  null|string  $url The url of the file. Only returned when the includeFileUrls option is provided.
     * @param  \Bushelpowered\Api\Platform\File\V1\Common\Attachment[]|null  $attachments The file attachments. Only returned when the includeAttachments option is provided.
     * @param  string  $createdAt Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $updatedAt Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $id, \Bushelpowered\Api\Platform\File\V1\Common\FileStore $store, \Bushelpowered\Api\Platform\File\V1\Common\FileType $fileType, string $displayName, string $contentType, string $sourceFileName, string $sourceContentType, int $size, string $createdBy, ?string $url, ?array $attachments, string $createdAt, string $updatedAt)
    {
        $this->id = $id;
        $this->store = $store;
        $this->fileType = $fileType;
        $this->displayName = $displayName;
        $this->contentType = $contentType;
        $this->sourceFileName = $sourceFileName;
        $this->sourceContentType = $sourceContentType;
        $this->size = $size;
        $this->createdBy = $createdBy;
        $this->url = $url;
        $this->attachments = $attachments;
        $this->createdAt = $createdAt;
        $this->updatedAt = $updatedAt;
    }
    
    /**
     * @return string Created date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getCreatedAt(): string
    {
        return $this->createdAt;
    }
    /**
     * @return string Updated date-time within the microservice. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getUpdatedAt(): string
    {
        return $this->updatedAt;
    }
}