<?php
namespace Bushelpowered\Api\Trade\Esign\V1\Request;
        
class PushDocumentRequest implements \Bushelpowered\Api\Trade\Esign\V1\Request\CreateDocumentWithEncodedPdf
{
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureBox[] $signatureBoxes The signature boxes to be placed on the document.*/
    public array $signatureBoxes;
    /** @var string $datasourceId The id of the datasource where this record came from.*/
    public string $datasourceId;
    /** @var null|string $customerTag The esign owner defined id. Known in the CMS as contract id. For pushed documents this is the pusher's remote id*/
    public ?string $customerTag = null;
    /** @var null|string $title The title of the document.*/
    public ?string $title = null;
    /** @var null|string $subject The subject of the document.*/
    public ?string $subject = null;
    /** @var null|string $message The message of the document.*/
    public ?string $message = null;
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\Owner $owner */
    public \Bushelpowered\Api\Trade\Esign\V1\Model\Owner $owner;
    /** @var \Bushelpowered\Api\Trade\Esign\V1\Model\Signer $signer */
    public \Bushelpowered\Api\Trade\Esign\V1\Model\Signer $signer;
    /** @var bool $isSigned Whether or not the document is signed by the creator.*/
    public bool $isSigned;
    /** @var string $pdf The PDF of the document base64 encoded.*/
    public string $pdf;

    /**
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\SignatureBox[]  $signatureBoxes The signature boxes to be placed on the document.
     * @param  string  $datasourceId The id of the datasource where this record came from.
     * @param  null|string  $customerTag The esign owner defined id. Known in the CMS as contract id. For pushed documents this is the pusher's remote id
     * @param  null|string  $title The title of the document.
     * @param  null|string  $subject The subject of the document.
     * @param  null|string  $message The message of the document.
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\Owner  $owner 
     * @param  \Bushelpowered\Api\Trade\Esign\V1\Model\Signer  $signer 
     * @param  bool  $isSigned Whether or not the document is signed by the creator.
     * @param  string  $pdf The PDF of the document base64 encoded.
     */
    public function __construct(array $signatureBoxes, string $datasourceId, ?string $customerTag, ?string $title, ?string $subject, ?string $message, \Bushelpowered\Api\Trade\Esign\V1\Model\Owner $owner, \Bushelpowered\Api\Trade\Esign\V1\Model\Signer $signer, bool $isSigned, string $pdf)
    {
        $this->signatureBoxes = $signatureBoxes;
        $this->datasourceId = $datasourceId;
        $this->customerTag = $customerTag;
        $this->title = $title;
        $this->subject = $subject;
        $this->message = $message;
        $this->owner = $owner;
        $this->signer = $signer;
        $this->isSigned = $isSigned;
        $this->pdf = $pdf;
    }
    
    /**
     * @return string The id of the datasource where this record came from.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return null|string The esign owner defined id. Known in the CMS as contract id. For pushed documents this is the pusher's remote id
     */
    public function getCustomerTag(): ?string
    {
        return $this->customerTag;
    }
    /**
     * @return null|string The title of the document.
     */
    public function getTitle(): ?string
    {
        return $this->title;
    }
    /**
     * @return null|string The subject of the document.
     */
    public function getSubject(): ?string
    {
        return $this->subject;
    }
    /**
     * @return null|string The message of the document.
     */
    public function getMessage(): ?string
    {
        return $this->message;
    }
    /**
     * @return \Bushelpowered\Api\Trade\Esign\V1\Model\Owner 
     */
    public function getOwner(): \Bushelpowered\Api\Trade\Esign\V1\Model\Owner
    {
        return $this->owner;
    }
    /**
     * @return \Bushelpowered\Api\Trade\Esign\V1\Model\Signer 
     */
    public function getSigner(): \Bushelpowered\Api\Trade\Esign\V1\Model\Signer
    {
        return $this->signer;
    }
    /**
     * @return bool Whether or not the document is signed by the creator.
     */
    public function getIsSigned(): bool
    {
        return $this->isSigned;
    }
    /**
     * @return string The PDF of the document base64 encoded.
     */
    public function getPdf(): string
    {
        return $this->pdf;
    }
}