<?php
namespace Bushelpowered\Api\Trade\Futures\V1\Model;
        
class FutureStandard 
{
    /** @var string $symbol The futures symbol in the format Commodity-Month-Year, e.g. 'EHG24'*/
    public string $symbol;
    /** @var string $contractDate The simple expiration date of the contract, e.g. '2014-03-14'*/
    public string $contractDate;
    /** @var string $change The change in price from the previous day's settlement price*/
    public string $change;
    /** @var int $changeSign The sign of the change in price from the previous day's settlement price*/
    public int $changeSign;
    /** @var string $close The closing price*/
    public string $close;
    /** @var null|string $settleUtcTime The UTC time of the day's settlement*/
    public ?string $settleUtcTime = null;
    /** @var string $tradeSettle If the market has settled, this is the settle price, otherwise it is the last trade price*/
    public string $tradeSettle;
    /** @var string $high The high price of the day*/
    public string $high;
    /** @var string $last The last trade price*/
    public string $last;
    /** @var string $bid The bid price*/
    public string $bid;
    /** @var string $low The low price of the day*/
    public string $low;
    /** @var string $open The opening price*/
    public string $open;
    /** @var string $previous The previous day's settlement price*/
    public string $previous;

    /**
     * @param  string  $symbol The futures symbol in the format Commodity-Month-Year, e.g. 'EHG24'
     * @param  string  $contractDate The simple expiration date of the contract, e.g. '2014-03-14'
     * @param  string  $change The change in price from the previous day's settlement price
     * @param  int  $changeSign The sign of the change in price from the previous day's settlement price
     * @param  string  $close The closing price
     * @param  null|string  $settleUtcTime The UTC time of the day's settlement
     * @param  string  $tradeSettle If the market has settled, this is the settle price, otherwise it is the last trade price
     * @param  string  $high The high price of the day
     * @param  string  $last The last trade price
     * @param  string  $bid The bid price
     * @param  string  $low The low price of the day
     * @param  string  $open The opening price
     * @param  string  $previous The previous day's settlement price
     */
    public function __construct(string $symbol, string $contractDate, string $change, int $changeSign, string $close, ?string $settleUtcTime, string $tradeSettle, string $high, string $last, string $bid, string $low, string $open, string $previous)
    {
        $this->symbol = $symbol;
        $this->contractDate = $contractDate;
        $this->change = $change;
        $this->changeSign = $changeSign;
        $this->close = $close;
        $this->settleUtcTime = $settleUtcTime;
        $this->tradeSettle = $tradeSettle;
        $this->high = $high;
        $this->last = $last;
        $this->bid = $bid;
        $this->low = $low;
        $this->open = $open;
        $this->previous = $previous;
    }
    

}